/*
    kopeteprefs.cpp - Kopete Preferences Container-Class

    Copyright (c) 2002      by Stefan Gehn            <sgehn@gmx.net>

    Kopete    (c) 2002-2003 by the Kopete developers  <kopete-devel@kde.org>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#include "kopeteprefs.h"

#include <kapplication.h>
#include <klocale.h>
#include <qcolor.h>
#include <kconfig.h>
#include <kglobal.h>
#include <kdebug.h>
#include <kopetechatwindow.h> // FIXME: I do not like this dependency; mETz

KopetePrefs *KopetePrefs::s_prefs = 0L;

KopetePrefs *KopetePrefs::prefs()
{
	if( !s_prefs )
		s_prefs = new KopetePrefs;
	return s_prefs;
}

KopetePrefs::KopetePrefs() : QObject( kapp, "KopetePrefs" )
{
	config = KGlobal::config();
	load();
}

KopetePrefs::~KopetePrefs()
{
//	save(); // crashes because KopeteApp is already destructed!
}

void KopetePrefs::load()
{
//	kdDebug(14010) << "KopetePrefs::load()" << endl;
	
	config->setGroup("Appearance");
	
	mIconTheme					= config->readEntry ( "EmoticonTheme", defaultTheme() );
	mUseEmoticons				= config->readBoolEntry ( "Use Emoticons", true );
	mShowOffline				= config->readBoolEntry ( "ShowOfflineUsers", true );
	mGreyIdle					= config->readBoolEntry ( "GreyIdleMetaContacts", true );
	mSortByGroup				= config->readBoolEntry ( "SortByGroup" , true );
	#if KDE_VERSION >= 306
	mNotifyOnline			= config->readBoolEntry ( "NotifyOnlineUsers", true );
	#endif
	mTreeView					= config->readBoolEntry ( "TreeView", true );
	mStartDocked				= config->readBoolEntry ( "StartDocked", false );
	mUseQueue					= config->readBoolEntry ( "Use Queue", true );
	mRaiseMsgWindow			= config->readBoolEntry ( "Raise Msg Window", true );
	mShowEvents					= config->readBoolEntry ( "Show Events in Chat Window", false );
	mTrayflashNotify			= config->readBoolEntry ( "Trayflash Notification", false );
	mBalloonNotify				= config->readBoolEntry ( "Balloon Notification", true );
	mSoundNotify				= config->readBoolEntry ( "Sound Notification", true );
	mSoundIfAway				= config->readBoolEntry ( "Sound Notification If Away");
	mBeepNotify					= config->readBoolEntry ( "Beep Notification", false );
	mChatWindowPolicy			= config->readNumEntry ( "Chatwindow Policy", 0 );
	mTransparencyEnabled		= config->readBoolEntry( "ChatView Transparency Enabled", false);
	mTransparencyValue		= config->readNumEntry( "ChatView Transparency Value", 50 );
	QColor tmpColor = QColor(255,255,255);
	mTransparencyColor		= config->readColorEntry("ChatView Transparency Tint Color", &tmpColor);
	mBgOverride					= config->readBoolEntry( "ChatView Override Background", true);
	mInterfacePreference		= config->readNumEntry( "Interface Preference", 1 );
/*
	mCTransparencyEnabled	= config->readBoolEntry( "ContactList Transparency Enabled", true);
	mCTransparencyValue		= config->readNumEntry( "ContactList Transparency Value", 50 );
	mCTransparencyColor		= config->readColorEntry("ContactList Transparency Tint Color", &tmpColor);
*/
	mShowTray					= config->readBoolEntry( "Show Systemtray", true);

	mKindMessagesHtml		= config->readEntry ( "MessagesHTML", KindMessagesHTML(0) );
}

void KopetePrefs::save()
{
//	kdDebug(14010) << "KopetePrefs::save()" << endl;

	config->setGroup ( "Appearance");

	config->writeEntry("EmoticonTheme", mIconTheme);
	config->writeEntry("Use Emoticons", mUseEmoticons);
	config->writeEntry("ShowOfflineUsers", mShowOffline);
	config->writeEntry("GreyIdleMetaContacts", mGreyIdle);
	#if KDE_VERSION >= 306
	config->writeEntry("NotifyOnlineUsers", mNotifyOnline);
	#endif
	config->writeEntry("TreeView", mTreeView);
	config->writeEntry("SortByGroup", mSortByGroup);
	config->writeEntry("StartDocked", mStartDocked);
	config->writeEntry("Use Queue", mUseQueue);
	config->writeEntry("Raise Msg Window", mRaiseMsgWindow);
	config->writeEntry("Show Events in Chat Window", mShowEvents);
	config->writeEntry("Trayflash Notification", mTrayflashNotify);
	config->writeEntry("Balloon Notification", mBalloonNotify);
	config->writeEntry("Sound Notification", mSoundNotify);
	config->writeEntry("Sound Notification If Away", mSoundIfAway);
	config->writeEntry("Beep Notification", mBeepNotify);
	config->writeEntry("MessagesHTML", mKindMessagesHtml);
	config->writeEntry("Chatwindow Policy", mChatWindowPolicy);
	config->writeEntry("ChatView Transparency Enabled", mTransparencyEnabled);
	config->writeEntry("ChatView Transparency Value", mTransparencyValue);
	config->writeEntry("ChatView Transparency Tint Color", mTransparencyColor);
	config->writeEntry("ChatView Override Background", mBgOverride);
	config->writeEntry("Interface Preference", mInterfacePreference);
/*
	config->writeEntry("ContactList Transparency Enabled", mCTransparencyEnabled);
	config->writeEntry("ContactList Transparency Value", mCTransparencyValue);
	config->writeEntry("ContactList Transparency Tint Color", mCTransparencyColor);
*/
	config->writeEntry("Show Systemtray", mShowTray);

	config->sync();
	emit saved();
}


void KopetePrefs::setIconTheme( const QString &value )
{
	mIconTheme = value;
}

void KopetePrefs::setUseEmoticons( bool value )
{
	mUseEmoticons = value;
}

void KopetePrefs::setShowOffline( bool value )
{
	mShowOffline = value;
}

#if KDE_VERSION >= 306
void KopetePrefs::setNotifyOnline( bool value )
{
	mNotifyOnline = value;
}
#endif

void KopetePrefs::setTreeView( bool value )
{
	mTreeView = value;
}

void KopetePrefs::setSortByGroup( bool value )
{
	mSortByGroup = value;
}

void KopetePrefs::setGreyIdleMetaContacts( bool value )
{
	mGreyIdle = value;
}

void KopetePrefs::setStartDocked( bool value )
{
	mStartDocked = value;
}

void KopetePrefs::setUseQueue( bool value )
{
	mUseQueue = value;
}

void KopetePrefs::setRaiseMsgWindow( bool value )
{
	mRaiseMsgWindow = value;
}

void KopetePrefs::setShowEvents( bool value )
{
	mShowEvents = value;
}

void KopetePrefs::setTrayflashNotify( bool value )
{
	mTrayflashNotify = value;
}

void KopetePrefs::setBalloonNotify( bool value )
{
	mBalloonNotify = value;
}

void KopetePrefs::setSoundNotify( bool value )
{
	mSoundNotify = value;
}

void KopetePrefs::setSoundIfAway( bool value )
{
	mSoundIfAway = value;
}

void KopetePrefs::setBeepNotify( bool value )
{
	mBeepNotify = value;
}

void KopetePrefs::setKindMessagesHtml( const QString &value )
{
	mKindMessagesHtml = value;
}

void KopetePrefs::setChatWindowPolicy( int value )
{
	mChatWindowPolicy = value;
}

void KopetePrefs::setInterfacePreference( int value )
{
	mInterfacePreference = value;
}

void KopetePrefs::setTransparencyEnabled( bool value)
{
	mTransparencyEnabled = value;
}

void KopetePrefs::setTransparencyColor( const QColor &value )
{
	mTransparencyColor = value;
}

void KopetePrefs::setTransparencyValue( int value )
{
	mTransparencyValue = value;
}

void KopetePrefs::setBgOverride( bool value )
{
	mBgOverride = value;
}

void KopetePrefs::setShowTray( bool value )
{
	mShowTray = value;
}

/*
	Code:
	%M : insert the Message
	%T : insert Timestamp
	%F : insert Fonts (the first open and the second close)
	%b : background color in html format ( #ABABAB )
	%f : insert the displayName of the sender
	%t : insert the displayName of the reciever

	%i ... %i : code between is parsed only if inbound
	%o ... %o : code between is parsed only if outbound
	%s ... %s : code between is parsed only if internal
	%e ... %e : code between is parsed only if not internal (external)

	%% : insert a '%'
*/
QString KopetePrefs::KindMessagesHTML( unsigned int k )
{
	QString start = QString::fromLatin1( "<table width=\"100%%\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\">" );
	QString end =   QString::fromLatin1( "</td></tr></table>" );

	switch( k )
	{
	case 1:
		// MSN Messenger
		return start + QString::fromLatin1( "<tr>%e<td colspan=\"2\"><font color=\"#606060\">" ) + i18n( "%f says:" ) +
			QString::fromLatin1( "</font></td></tr><tr><td width=\"15\">&nbsp;</td>%e<td width=\"100%%\" bgcolor=\"%b\"> %F%M%F " ) + end;
	case 2:
		// IRC
		return start + QString::fromLatin1(
			"<tr><td bgcolor=\"%b\"> %i<font color=\"#0360B1\">%i "
			"%o<font color=\"#E11919\">%o %s<font color=\"#000000\"><i>%s"
			" (%T) %e<b>%f:</b>%e%s</i>%s</font> %F%M%F " ) + end;
	case 0:
	default:
		// Kopete Default
		return start + QString::fromLatin1( " %e<tr><td>%i<font color=\"#0360B1\"><b>" ) +
		i18n( "Message from %f %i %o" ) + QString::fromLatin1( "<font color=\"#E11919\"><b>" ) +
		i18n( "Message to %t %o at %T" ) + QString::fromLatin1( "</b></font></td></tr>%e <tr><td bgcolor=\"%b\"> %F%M%F " ) + end;
	}
}

/*
void KopetePrefs::setCTransparencyEnabled( bool value)
{
	mCTransparencyEnabled = value;
}

void KopetePrefs::setCTransparencyColor( const QColor &value )
{
	mCTransparencyColor = value;
}

void KopetePrefs::setCTransparencyValue( int value )
{
	mCTransparencyValue = value;
}
*/

#include "kopeteprefs.moc"

// vim: set noet ts=4 sts=4 sw=4:
